/**
  *  \file client/dialogs/commandedit.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/dialogs/commandedit.h"
#include "client/widgets/commandlist.h"
#include "game/global.h"
#include "game/team.h"
#include "ui/layout.h"
#include "util/nls.h"
#include "ui/window.h"
#include "ui/widgets.h"
#include "gfx/palette.h"
#include "ui/msgbox.h"
#include "client/widgets/commandinfo.h"
#include "ui/widgets/keytranslator.h"

namespace {
    class WCommandEditDialog : public UIWindow {
        ObjectHolder h;
        WCommandList list;
        WCommandInfo info;

        void buildDialog();
        void onScroll();
     public:
        WCommandEditDialog();
        ~WCommandEditDialog();
    };
}

WCommandEditDialog::WCommandEditDialog()
    : UIWindow(_("Auxiliary Commands"), BLUE_WINDOW, COLOR_GRAY),
      list(getDisplayedTurn().getCommands(getPlayerId())),
      info()
{
    buildDialog();
    onScroll();
    list.sig_moved.add(this, &WCommandEditDialog::onScroll);
}

WCommandEditDialog::~WCommandEditDialog()
{ }

void
WCommandEditDialog::buildDialog()
{
    // VBox
    //   Frame
    //     WCommandList
    //     UIScrollbar
    //   WCommandInfo
    //   HBox
    //     UIButton "Close"
    //     UIButton "Del"
    //     UIButton "Ins"
    //     UISpacer
    //    [UIButton "Help"]

    setLayout(UIVBoxLayout::instance5);

    UIFrameGroup& group1 = h.add(new UIFrameGroup(UIHBoxLayout::instance0));
    group1.add(list);
    group1.add(h.add(new UIScrollbar(list)));

    UIGroup& group2 = h.add(new UIGroup(UIHBoxLayout::instance5));
    group2.add(h.add(new UIButton(0, _("Close"), SDLK_RETURN)).addStop());
    group2.add(h.add(new UIButton(_("Del"),   SDLK_DELETE)));
    group2.add(h.add(new UIButton(_("Ins"),   SDLK_INSERT)));
    group2.add(h.add(new UISpacer()));

    add(group1);
    add(info);
    add(group2);

    add(h.add(new UIKeyTranslator()).addStop(SDLK_ESCAPE, 0));

    list.setFocusedWidget();
    pack();
}

void
WCommandEditDialog::onScroll()
{
    info.setCommand(list.getCurrentCommand());
}

void
editCommands()
{
    WCommandEditDialog edit;
    ui_root->centerWidget(edit);
    ui_root->runModal(edit);
}
