/**
  *  \file client/tiles/planetoverview.cc
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/tiles/planetoverview.h"
#include "ui/uiglobal.h"
#include "cpluslib/format.h"
#include "util/nls.h"
#include "game/planet.h"
#include "game/tables.h"
#include "util/misc.h"
#include "game/racename.h"

/************************** WPlanetOverviewTile **************************/

WPlanetOverviewTile::WPlanetOverviewTile(GObjectType& type)
    : WObjectTypeObserverTile(font_sizes[FONT_NORMAL].scaledBy(30, 10), type)
{ }

void
WPlanetOverviewTile::drawData(GfxCanvas& can)
{
    GPlanet* p = dynamic_cast<GPlanet*>(getObject());
    if (!p)
        return;

    GPlanet& pp = *p;
    UISkin& sk = getSkin();
    sk.startDraw();

    int y = getExtent().y, x = getExtent().x;

    /* location, climate */
    sk.outTextF(can, FONT_NORMAL, x, y, 130, format(_("Climate: %s"), getTemperatureName(pp.getTemperature())));
    if (int sector = pp.getPos().getSectorNumber())
        sk.outTextF(can, FONT_NORMAL, x+130, y, extent.w - 130,
                    format(_("Location: (%d,%d) - Sector %d"),
                           pp.getPos().x, pp.getPos().y, sector));
    else
        sk.outTextF(can, FONT_NORMAL, x+130, y, extent.w - 130,
                    format(_("Location: (%d,%d)"),
                           pp.getPos().x, pp.getPos().y));
    y += font_heights[FONT_NORMAL]+2;

    // FIXME: I don't really like this because it uses hard
    // measurements (the same as in PCC 1.x)
    /*  |-35-|---70---|5|---95---|30|----175--------|
        Col:  N,NNN,NNN Race      xx% -> happy (100)
        Nat:  N,NNN,NNN Race
        |0   |35      |105|110   |205|235  */
    
    /* colonists */
    sk.outTextF(can, FONT_NORMAL, x,   y, 35, _("Col:"));
    if (pp.getOwner()) {
        sk.outTextF(can, FONT_NORMAL, x+110, y, 95, player_racenames.getAdjName(pp.getOwner()));
        sk.outTextF(can, FONT_NORMAL, x+235, y, 155,
                    format(" -> %s (%d)", getHappinessName(pp.getColonistHappiness()),
                           pp.getColonistHappiness()));
        sk.getParameters().just_x = 2;
        sk.outTextF(can, FONT_NORMAL, x+105, y, 70, clansToString(pp.getColonists()));
        sk.outTextF(can, FONT_NORMAL, x+235, y, 30, format("%d%%", pp.getColonistTax()));
        sk.getParameters().just_x = 0;
    } else {
        sk.outTextF(can, FONT_NORMAL, x+35, y, 70+5+95+30+155, _("none"));
    }
    y += font_heights[FONT_NORMAL];

    /* natives */
    sk.outTextF(can, FONT_NORMAL, x, y, 35, _("Nat:"));
    if (pp.getNativeRace()) {
        sk.outTextF(can, FONT_NORMAL, x+110, y, 95, getNativeRaceName(pp.getNativeRace()));
        sk.outTextF(can, FONT_NORMAL, x+235, y, 155,
                    format(" -> %s (%d)", getHappinessName(pp.getNativeHappiness()),
                           pp.getNativeHappiness()));
        sk.getParameters().just_x = 2;
        sk.outTextF(can, FONT_NORMAL, x+105, y, 70, clansToString(pp.getNatives()));
        sk.outTextF(can, FONT_NORMAL, x+235, y, 30, format("%d%%", pp.getNativeTax()));
        sk.getParameters().just_x = 0;
    } else {
        sk.outTextF(can, FONT_NORMAL, x+35, y, 70+5+95+30+155, _("none"));
    }
    y += font_heights[FONT_NORMAL]+2;

    /* industry */
    sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
                format(_("Mines: %d; Factories: %d; Defense Posts: %d"),
                       pp.getStructures(str_Mines),
                       pp.getStructures(str_Factories),
                       pp.getStructures(str_Defense)));
    y += font_heights[FONT_NORMAL];

    sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
                format(_("%d mc; %d kt supplies"),
                       pp.getCargo(el_Money), pp.getCargo(el_Supplies)));
    y += font_heights[FONT_NORMAL];

    /* minerals */
    sk.outTextF(can, FONT_NORMAL, x, y, 50, _("Mined:"));
    sk.getParameters().just_x = 2;
    sk.outTextF(can, FONT_NORMAL, x+130, y, 80, format("%dN", pp.getCargo(el_Neutronium)));
    sk.outTextF(can, FONT_NORMAL, x+210, y, 80, format("%dT", pp.getCargo(el_Tritanium)));
    sk.outTextF(can, FONT_NORMAL, x+290, y, 80, format("%dD", pp.getCargo(el_Duranium)));
    sk.outTextF(can, FONT_NORMAL, x+370, y, 80, format("%dM", pp.getCargo(el_Molybdenum)));
    y += font_heights[FONT_NORMAL];
    
    sk.outTextF(can, FONT_NORMAL, x+130, y, 80, format("%dN", pp.getOreGround(el_Neutronium)));
    sk.outTextF(can, FONT_NORMAL, x+210, y, 80, format("%dT", pp.getOreGround(el_Tritanium)));
    sk.outTextF(can, FONT_NORMAL, x+290, y, 80, format("%dD", pp.getOreGround(el_Duranium)));
    sk.outTextF(can, FONT_NORMAL, x+370, y, 80, format("%dM", pp.getOreGround(el_Molybdenum)));
    sk.getParameters().just_x = 0;
    sk.outTextF(can, FONT_NORMAL, x, y, 50, _("Ground:"));
    y += font_heights[FONT_NORMAL] + 2;

    sk.outTextF(can, FONT_NORMAL, x, y, extent.w,
                format(_("Friendly Code: %s"), pp.getFCode()));

    can.update(getExtent());
}

