/**
  *  \file game/actions/baseship.h
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_GAME_ACTIONS_BASESHIP_H
#define PCC_V2_GAME_ACTIONS_BASESHIP_H

#include "game/actions/basebuild.h"
#include "game/planet.h"

class GStarbaseBuildShipAction : public GStarbaseBuildAction {
    TBuildOrder        order;
    bool               use_parts_from_storage : 1;
    bool               use_tech_upgrade       : 1;
    bool               is_ok                  : 1;

    void  doTechUpgrade(TTechLevel tl, GStarbaseBuildExecuter& a, int need);
    int   getBuildAmount(int need, int have);

 public:
    GStarbaseBuildShipAction(GPlanet& planet);
    ~GStarbaseBuildShipAction();

    bool  isUsePartsFromStorage() const;
    bool  isUseTechUpgrade() const;
    void  setUsePartsFromStorage(bool b);
    void  setUseTechUpgrade(bool b);

    void                setBuildOrder(TBuildOrder o);
    const TBuildOrder&  getBuildOrder() const;

    GError getError();

    bool isOK() const
        { return is_ok; }

    void perform(GStarbaseBuildExecuter& a);

    static bool prepareBuildOrder(TBuildOrder& o, const GPlanet& p);
};


inline bool
GStarbaseBuildShipAction::isUsePartsFromStorage() const
{
    return use_parts_from_storage;
}

inline bool
GStarbaseBuildShipAction::isUseTechUpgrade() const
{
    return use_tech_upgrade;
}

inline const TBuildOrder&
GStarbaseBuildShipAction::getBuildOrder() const
{
    return order;
}

#endif
