/**
  *  \file int/globalif.h
  *  \brief Interpreter Game Interface: Global Functions and Properties
  */
#ifndef PCC_V2_INT_GLOBALIF_H
#define PCC_V2_INT_GLOBALIF_H

#include "cpluslib/types.h"
#include "int/context.h"

class IntValue;
class IntDataSegment;

class IntGlobalContext : public IntSingleContext {
 public:
    IntGlobalContext();
    ~IntGlobalContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    IntContext* clone();
};

enum IntGlobalProperty {
    igpSystemProgram,
    igpSystemVersion,
    igpSystemVersionCode,
    igpSystemHost,
    igpSystemHostCode,
    igpSystemHostVersion
};

IntValue* getGlobalProperty(IntGlobalProperty igp);

IntValue* IFDistanceGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFShipNameGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFPlanetNameGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFCfgGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFIsSpecialFCodeGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFTruehull(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntValue* IFRandomFCode(IntDataSegment& dseg, uint32_t index, uint32_t nargs);

#endif
