/**
  *  \file int/if/hullif.h
  *  \brief Interpreter Game Interface: Hull Properties
  */
#ifndef PCC_V2_INT_IF_HULLIF_H
#define PCC_V2_INT_IF_HULLIF_H

#include "int/value.h"
#include "int/context.h"

class GHull;
class IntDataSegment;

IntValue*   IFHullGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFHullMake();

/** Hull context. */
class IntHullContext : public IntContext {
    int hid;
 public:
    IntHullContext(int hid);
    ~IntHullContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
};

/** Definition of hull properties. */
enum IntHullProperty {
    ihpMaxBeams,
    ihpMaxCargo,
    ihpMaxFuel,
    ihpMaxCrew,
    ihpNumEngines,
    ihpNumFighterBays,
    ihpSpecial,
    ihpImage,
    ihpImage2,
    ihpMaxTorpLaunchers
};

IntValue* getHullProperty(const GHull& h, IntHullProperty isp);
void      setHullProperty(GHull& h, IntHullProperty isp, IntValue* value);

#endif
