/**
  *  \file int/if/ionif.h
  *  \brief Interpreter Game Interface: Ion Storms
  */
#ifndef PCC_V2_INT_IF_IONIF_H
#define PCC_V2_INT_IF_IONIF_H

#include "int/context.h"
#include "cpluslib/types.h"

class IntValue;
class IntDataSegment;
class GIonStorm;

IntValue*   IFIonGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFIonMake();

/** Ion Storm context. */
class IntIonContext : public IntContext {
    int iid;
 public:
    IntIonContext(int iid);
    ~IntIonContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
};

/** Ion Storm property identifier. */
enum IntIonProperty {
    iipClass,
    iipHeadingInt,
    iipHeadingName,
    iipId,
    iipLocX,
    iipLocY,
    iipName,
    iipRadius,
    iipSpeedInt,
    iipSpeedName,
    iipStatusFlag,
    iipStatusName,
    iipVoltage
};

IntValue* getIonProperty(const GIonStorm& ion, IntIonProperty iip);
void      setIonProperty(GIonStorm& ion, IntIonProperty iip, IntValue* value);

#endif
