/**
  *  \file int/if/shipif.h
  *  \brief Interpreter Game Interface: Ships
  */
#ifndef PCC_V2_INT_IF_SHIPIF_H
#define PCC_V2_INT_IF_SHIPIF_H

#include "int/compound.h"
#include "int/context.h"

class GShip;

IntValue*   IFShipGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFShipMake();

/** Ship context. */
class IntShipContext : public IntContext {
    int sid;
 public:
    IntShipContext(int sid);
    ~IntShipContext();

    // IntContext:
    int32_t   lookup(string_t name);
    void      set(int32_t index, IntValue* value);
    IntValue* get(int32_t index);
    bool      next();
    IntContext* clone();
};

/** Definition of ship properties. */
enum IntShipProperty {
    ispAUX_,
    ispAUX_AMMO,
    ispAUX_COUNT,
    ispAUX_SHORT,
    ispAUX,
    ispBEAM_,
    ispBEAM_COUNT,
    ispBEAM_SHORT,
    ispBEAM,
    ispCARGO_COLONISTS,
    ispCARGO_D,
    ispCARGO_FREE,
    ispCARGO_M,
    ispCARGO_MONEY,
    ispCARGO_N,
    ispCARGO_STR,
    ispCARGO_SUPPLIES,
    ispCARGO_T,
    ispCREW,
    ispDAMAGE,
    ispENGINE_,
    ispENGINE,
    ispFCODE,
    ispFIGHTER_BAYS,
    ispFIGHTER_COUNT,
    ispFLEET_,
    ispFLEET_NAME,
    ispFLEET_STATUS,
    ispFLEET,
    ispHEADING_,
    ispHEADING,
    ispHULL_,
    ispHULL_SHORT,
    ispHULL_SPECIAL,
    ispID,
    ispLEVEL,
    ispLOC_X,
    ispLOC_Y,
    ispLOC,
    ispMARKED,
    ispMASS,
    ispMISSION_,
    ispMISSION_INTERCEPT,
    ispMISSION_SHORT,
    ispMISSION_TOW,
    ispMISSION,
    ispMOVE_ETA,
    ispMOVE_FUEL,
    ispNAME,
    ispORBIT_,
    ispORBIT,
    ispOWNER_REAL,
    ispSPEED_,
    ispSPEED,
    ispTASK,
    ispTORP_,
    ispTORP_COUNT,
    ispTORP_LCOUNT,
    ispTORP_SHORT,
    ispTORP,
    ispTRANSFER_SHIP_COLONISTS,
    ispTRANSFER_SHIP_D,
    ispTRANSFER_SHIP_ID,
    ispTRANSFER_SHIP_M,
    ispTRANSFER_SHIP_N,
    ispTRANSFER_SHIP_NAME,
    ispTRANSFER_SHIP_SUPPLIES,
    ispTRANSFER_SHIP_T,
    ispTRANSFER_SHIP,
    ispTRANSFER_UNLOAD_COLONISTS,
    ispTRANSFER_UNLOAD_D,
    ispTRANSFER_UNLOAD_ID,
    ispTRANSFER_UNLOAD_M,
    ispTRANSFER_UNLOAD_N,
    ispTRANSFER_UNLOAD_NAME,
    ispTRANSFER_UNLOAD_SUPPLIES,
    ispTRANSFER_UNLOAD_T,
    ispTRANSFER_UNLOAD,
    ispTYPE_SHORT,
    ispTYPE,
    ispWAYPOINT_DIST,
    ispWAYPOINT_DX,
    ispWAYPOINT_DY,
    ispWAYPOINT_PLANET,
    ispWAYPOINT_X,
    ispWAYPOINT_Y,
    ispWAYPOINT
};

IntValue* getShipProperty(GShip& sh, IntShipProperty isp);
void      setShipProperty(GShip& sh, IntShipProperty isp, IntValue* value);

#endif
