/**
  *  \file int/if/specif.h
  *  \brief Interpreter Game Interface: Specification Access
  */
#ifndef PCC_V2_INT_IF_SPECIF_H
#define PCC_V2_INT_IF_SPECIF_H

#include "cpluslib/types.h"
#include "int/context.h"

class GComponent;
class GEngine;
class GWeapon;
class IntDataSegment;
class IntValue;

IntValue*   IFTorpedoGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFTorpedoMake();
IntValue*   IFLauncherGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFLauncherMake();
IntValue*   IFBeamGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFBeamMake();
IntValue*   IFEngineGet(IntDataSegment& dseg, uint32_t index, uint32_t nargs);
IntContext* IFEngineMake();

class IntTorpedoContext : public IntContext {
    int id;
 public:
    IntTorpedoContext(int id);
    ~IntTorpedoContext();
    int32_t     lookup(string_t name);
    void        set(int32_t index, IntValue* value);
    IntValue*   get(int32_t index);
    bool        next();
    IntContext* clone();
};

class IntLauncherContext : public IntContext {
    int id;
 public:
    IntLauncherContext(int id);
    ~IntLauncherContext();
    int32_t     lookup(string_t name);
    void        set(int32_t index, IntValue* value);
    IntValue*   get(int32_t index);
    bool        next();
    IntContext* clone();
};

class IntBeamContext : public IntContext {
    int id;
 public:
    IntBeamContext(int id);
    ~IntBeamContext();
    int32_t     lookup(string_t name);
    void        set(int32_t index, IntValue* value);
    IntValue*   get(int32_t index);
    bool        next();
    IntContext* clone();
};

class IntEngineContext : public IntContext {
    int id;
 public:
    IntEngineContext(int id);
    ~IntEngineContext();
    int32_t     lookup(string_t name);
    void        set(int32_t index, IntValue* value);
    IntValue*   get(int32_t index);
    bool        next();
    IntContext* clone();
};

/** Property for a GComponent. */
enum IntComponentProperty {
    icpMass,
    icpTech,
    icpCostT,
    icpCostD,
    icpCostM,
    icpCostMC,
    icpCostSup,
    icpCostStr,
    icpName,
    icpNameShort,
    icpId
};

/** Property for a GWeapon. */
enum IntWeaponProperty {
    iwpKill,
    iwpDamage
    // TorpCost? PCC 1.x doesn't have it.
};

/** Property for a GEngine. */
enum IntEngineProperty {
    iepEfficientWarp,
    iepFuelFactor
};

IntValue* getComponentProperty(const GComponent& comp, IntComponentProperty icp);
IntValue* getWeaponProperty(const GWeapon& w, IntWeaponProperty iwp, bool isTorpedo);
IntValue* getEngineProperty(const GEngine& e, IntEngineProperty iep);

#endif
