/**
  *  \file int/interror.h
  *  \brief Interpreter: Error messages
  */
#ifndef PCC_V2_INT_INTERROR_H
#define PCC_V2_INT_INTERROR_H

#include "cpluslib/string.h"
#include "game/error.h"

class IntError : public std::exception {
    string_t error;
 public:
    IntError(const char* error);
    IntError(string_t error);
    ~IntError() throw();

    const char* what() const throw();

    enum ExpectedType {
        tyNone,
        tyInteger,
        tyBool,                 // needed?
        tyNumeric,
        tyString,
        tyIndexable,
        tyIterable,
        tyRecord
    };

    static IntError unknownIdentifier();
    static IntError typeError(ExpectedType expectedType = tyNone);
    static IntError internalError(const char* msg);
    static IntError notSerializable();
    static IntError notAssignable();
    static IntError rangeError();
};



#endif
