/**
  *  \file int/intglobal.h
  *  \brief Interpreter: Global Definitions
  *
  *  This module contains global name definitions (symbol tables)
  *  and values (user-defined properties, variables).
  *
  *  (c) 2001-2010 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_INTGLOBAL_H
#define PCC_V2_INT_INTGLOBAL_H

#include "cpluslib/ptrvector.h"

class IntVariableNames;
class IntDataSegment;
class IntContext;

extern IntVariableNames planet_property_names;
extern IntVariableNames ship_property_names;
extern IntVariableNames global_property_names;
extern IntDataSegment global_values;
extern ptr_vector<IntContext> global_contexts;

/** Temporary context. Manages lifetime for a context temporarily
    added to global_contexts. */
class IntTemporaryContext {
    IntContext* con;
 public:
    IntTemporaryContext(IntContext* con);
    ~IntTemporaryContext();

    IntContext* operator->() const
        { return con; }
    IntContext& operator*() const
        { return *con; }
};

// Planet Properties
enum {
    pp_Comment = 0
};
// Ship Properties
enum {
    sp_Comment = 0
};

void initInterpreter();
void clearInterpreterGameData();

IntDataSegment& getShipProperties(int sid);
IntDataSegment& getPlanetProperties(int pid);

#endif
