#include "io/rle.h"
#include "u/t_io.h"

#include "io/memstream.h"

char buffer[10240];

void test_bad(string_t data, std::size_t amount)
{
    try {
        RleReaderStream rs(new MemoryStream(data));
        rs.read(buffer, amount);
        TS_ASSERT(0);
    }
    catch(...) { }
}

void test_ok(string_t data, string_t decoded)
{
    try {
        RleReaderStream rs(new MemoryStream(data));
        size_t got = rs.read(buffer, decoded.length());
        TS_ASSERT_EQUALS(got, decoded.length());
        TS_ASSERT_EQUALS(decoded.compare(0, decoded.length(), buffer, decoded.length()), 0);
    }
    catch(...) {
        TS_ASSERT(0);
    }
}

void
IoRleTestSuite::testMain()
{
    // some tests for bad compression
    test_bad("", 0);
    test_bad("xxx", 0);
    test_bad(string_t(3, '\0'), 0);
    // Although not good compression, this one's interpreted as EOF
    // test_bad(string_t(5, '\0'), 8);
    test_bad(string_t("\1\0\0\0\0", 5), 8);
    test_bad(string_t("\10\0\0\0\10\0", 6), 8);
    test_bad(string_t("\10\0\0\0\10\0\3", 7), 8);
    test_bad(string_t("\10\0\0\0\10\0\3\3", 8), 8);
    test_bad(string_t("\10\0\0\0\10\0\3\3\3", 9), 8);
    test_bad(string_t("\10\0\0\0\10\0\3x\3\3", 10), 8);
    test_bad(string_t("\10\0\0\0\10\0\3abcdef\2\3", 16), 8);
    test_bad(string_t("\10\0\0\0\10\0\3abcdef\3\3\3", 16), 8);

    // some tests for good compression
    test_ok(string_t("\0\0\0\0", 4), "");
    test_ok(string_t("\10\0\0\0\10\0\3foo", 10), "foo");
    test_ok(string_t("\10\0\0\0\10\0\3f\3\5ox", 12), "fooooox");
    test_ok(string_t("\10\0\0\0\4\0\3f\3\3o\4\0\7\7\3ox", 18), "foooooox");
}
